niftianon
=========

Anonymiser for NIFTI format images.


Installation
------------

Latest stable release from pip
++++++++++++++++++++++++++++++

.. code::

    pip install niftianon


Latest development version from Github
++++++++++++++++++++++++++++++++++++++

.. code::

    git clone https://github.com/jstutters/niftianon
    cd niftianon
    pip install .


Usage
-----

.. code::

    niftianon [path to identifiable image] [path to anonymised image]

The anonymised image path must not exist.


Contribute
----------

- Issue Tracker: `github.com/jstutters/niftianon/issues <http://github.com/jstutters/niftianon/issues>`_
- Source Code: `github.com/jstutters/niftianon <http://github.com/jstutters/niftianon>`_


Support
-------

If you are having problems, please let me know by submitting an issue in the `tracker <http://github.com/jstutters/niftianon/issues>`_.


License
-------

niftianon is licensed under the `MIT license <https://opensource.org/licenses/MIT>`_.
